library(rjags)
library(R2jags)
library (coda)
library(boa)
library (tidyverse)

# dataset to analyse (change as appropriate)

d = CMJBw # SJBw

# design matrix (can include more predictors including interactions etc)
x = (model.matrix( ~  SEX+TIME+GROUP+TIME:GROUP, d))
np = dim(x)[2] # nunber of columns in design matrix

# response variable
y =  d$JUMP_MAX
# subject ID
d$SUBJ <- factor(d$SUBJ)
ID = d$SUBJ
N_obs = length(ID) # number of rows
N_subj = length(unique(ID)) # number of subjects

# Vague normal prior hyperparameter values for regression coefficients
mu <- rep(0,np) 
prec.mu <- rep(0.001,np) 

# data
jags.data <- list("y",
                  "x","N_obs","N_subj","mu","prec.mu","ID","np")

# model parameter to keep track of 
jags.params <- c("beta","sigma.u","sigma.y")

# initialising the MCMC
jags.inits <- function() { list(beta=rep(0.1,np),tau.u=10,u=rnorm(N_subj,0,sqrt(1/10))) }

model_file = "./JAGS_FILE.txt"
# Call JAGS to run the MCMC (1000 iterations of burnin, then another 50K iterations, thinning by factor of 10 to produce 5K posterior samples)
jagsfit_cmj <- jags(data=jags.data, inits=jags.inits, jags.params,n.chains=1,n.thin=10,DIC=TRUE,
                n.iter=51000,n.burnin=1000, model.file=model_file, set.seed(100) )

jagsfit_sj <- jags(data=jags.data, inits=jags.inits, jags.params,n.chains=1,n.thin=10,DIC=TRUE,
                    n.iter=51000,n.burnin=1000, model.file=model_file, set.seed(100) )

jagsfit = jagsfit_cmj #jagsfit_sj
